@@ -14,6 +14,10 @@ gboolean
 fwupd_client_connect(FwupdClient *self,
 		     GCancellable *cancellable,
 		     GError **error) G_GNUC_WARN_UNUSED_RESULT;
+gboolean
+fwupd_client_quit(FwupdClient *self,
+		  GCancellable *cancellable,
+		  GError **error) G_GNUC_WARN_UNUSED_RESULT;
 GPtrArray *
 fwupd_client_get_devices(FwupdClient *self,
 			 GCancellable *cancellable,
@@ -66,6 +70,16 @@ fwupd_client_unlock(FwupdClient *self,
 		    const gchar *device_id,
 		    GCancellable *cancellable,
 		    GError **error) G_GNUC_WARN_UNUSED_RESULT;
+gchar *
+fwupd_client_inhibit(FwupdClient *self,
+		     const gchar *reason,
+		     GCancellable *cancellable,
+		     GError **error) G_GNUC_WARN_UNUSED_RESULT;
+gboolean
+fwupd_client_uninhibit(FwupdClient *self,
+		       const gchar *inhibit_id,
+		       GCancellable *cancellable,
+		       GError **error) G_GNUC_WARN_UNUSED_RESULT;
 gboolean
 fwupd_client_modify_config(FwupdClient *self,
 			   const gchar *key,
@@ -240,5 +254,14 @@ fwupd_client_upload_bytes(FwupdClient *self,
 			  FwupdClientUploadFlags flags,
 			  GCancellable *cancellable,
 			  GError **error) G_GNUC_WARN_UNUSED_RESULT;
+gboolean
+fwupd_client_emulation_load(FwupdClient *self,
+			    GBytes *data,
+			    GCancellable *cancellable,
+			    GError **error);
+GBytes *
+fwupd_client_emulation_save(FwupdClient *self,
+			    GCancellable *cancellable,
+			    GError **error) G_GNUC_WARN_UNUSED_RESULT;
 
 G_END_DECLS
